/************************************************************************
* File:        GRAPHICS.H
* Description: Header file for our graphics module.
* Author:      Jesse Towner.
************************************************************************/

#ifndef __GRAPHICS_H_
#define __GRAPHICS_H_

#include "color.h"

#ifdef __cplusplus
extern "C" {
#endif


/* D E F I N E S *********************************************************/


#define GFX_SCR_WIDTH  320
#define GFX_SCR_HEIGHT 200

#define true    1
#define false   0


/* S T R U C T U R E S ***************************************************/


typedef struct gfxBitmap_t {
	int width, height;
	int bpp;
	void * surface;
	gfxPalette_t palette;
	} gfxBitmap_t;


/* E X T E R N A L S *****************************************************/


extern unsigned char * gfxScreenPtr;


/* P R O T O T Y P E S ***************************************************/


void GFX_SetMode13h(void);
void GFX_SetTextMode(void);
unsigned char * GFX_CreateBuffer(void);
void GFX_DestroyBuffer(unsigned char * buffer);
gfxBitmap_t * GFX_CreateBitmap(int width, int height, int bpp);
void GFX_DestroyBitmap(gfxBitmap_t * bitmap);

void GFX_ClrScr(unsigned char * buffer, int color);
void GFX_BitBlt(unsigned char * dest, unsigned char * source);
void GFX_PutPixel(unsigned char * buffer, int x, int y, int color);
void GFX_PutPixelTrans(unsigned char * buffer, int x, int y, int color);
void GFX_PutPixelTransASM(unsigned char * buffer, int x, int y, int color);
void GFX_Rectangle(unsigned char * buffer, int x1, int y1, int x2, int y2, int color);
void GFX_RectangleTrans(unsigned char * buffer, int x1, int y1, int x2, int y2, int color);
void GFX_RectangleTransASM(unsigned char * buffer, int x1, int y1, int x2, int y2, int color);
void GFX_PutImage(unsigned char * buffer, unsigned char * image, int x1, int y, int width, int height);
void GFX_PutImageTrans(unsigned char * buffer, unsigned char * image, int x1, int y, int width, int height);
void GFX_PutImageTransASM(unsigned char * buffer, unsigned char * image, int x1, int y, int width, int height);

void GFX_PutPixel24(void * buffer24, int x, int y, int color);
void GFX_PutPixelTrans24(void * buffer24, int x, int y, int color, int alpha);
void GFX_PutPixelTransASM24(void * buffer24, int x, int y, int color, int alpha);


#ifdef __cplusplus
};
#endif

#endif

/* end of file */