/************************************************************************
* File:        TRANS.H
* Description: Header file for our translucency and alpha blending code.
* Author:      Jesse Towner.
************************************************************************/

#ifndef __TRANS_H_
#define __TRANS_H_

#ifdef __cplusplus
extern "C" {
#endif


/* S T R U C T U R E S *************************************************/


/* The Color Look-Up Table (CLUT) structure. This can be used for
   alpha blending using color indirection (256 color modes). It
   can also be used for lighting and other special effects, but
   I haven't included that in this package. Perhaps another time <g>. */
typedef struct gfxClut_t {
	unsigned char data[256][256];     /* Pointer to CLUT color info. */
	} gfxClut_t;


/* The Alpha Blending function map. This will be used in high/true
   color modes to blend colors without the restriction of color
   palettes. It can also be used in 256 color video modes, but
   it will require aditional look-up tables to convert an indexed
   color into it's direct RGB form. This map requires 256 functions
   where each function index corresponds to an alpha between 0
   and 255. The function will blend the colors together based on
   the index value. */
typedef struct gfxAlphaBlendMap_t {
	unsigned int cdecl (* blend[256])(unsigned int c1, unsigned int c2);
	} gfxAlphaBlendMap_t;


/* E X T E R N A L S *****************************************************/


extern gfxClut_t * gfxActiveClut;
extern gfxAlphaBlendMap_t gfxAlphaBlendMap24;


/* P R O T O T Y P E S ***************************************************/


void GFX_CreateTransTable(gfxClut_t * clut, gfxPalette_t pal, int alpha, void (* callback)(int pos));
void GFX_SetActiveTransTable(gfxClut_t * clut);


#ifdef __cplusplus
};
#endif

#endif

/* end of file */